﻿<%@ Page Language="C#" Inherits="System.Web.Mvc.ViewPage<MigrationModel>" %>
<%@ Import Namespace="EPiServer.Commerce.UI.Models.Migrate" %>
<%@ Import Namespace="EPiServer.Commerce.Internal.Migration" %>
<%@ Import Namespace="EPiServer.Shell" %>
<%@ Import Namespace="EPiServer.Framework.Web.Resources" %>
<%@ Import Namespace="System.Web.Mvc" %>

<html>
<head>
    <title>EPiServer Commerce Migration</title>
    <% if (Model.Status == MigrationStatus.InProgress){ %>
    <meta http-equiv="refresh" content="5" />
    <%} %>

    <%= Page.ClientResources("EPi.Shell.UI", new[] { ClientResourceType.Style }) %>
    <link rel="stylesheet" type="text/css" href="<%= Paths.ToClientResource("CMS", "ClientResources/epi-cms/epi.css") %>"></link>
    <link rel="stylesheet" type="text/css" href="<%= Paths.ToClientResource("EPiServer.Commerce.Shell", "ClientResources/epi-ecf-ui/epiCommerce.css") %>"></link>
    <style>
        @media (max-width: 767px) { .hidden-sm { display: none !important; } }
    </style>
</head>
<body class="Sleek">
    <div class="epi-view-container epi-view-container--scrollable">
        <div <%= Model.Status == MigrationStatus.InProgress ? "class=\"hidden-sm\"" : "" %>>
            <h1>EPiServer Commerce Migration</h1>
           
            <p>
                As a part of updating EPiServer Commerce you may be required to execute migration steps in the 
                context of the web site. Below you can see pending as well as historical migration steps.
            </p>
           
            <%if(Model.ShowHelp)
              { %> 
            <h2>Extended Information</h2>   
            <h3>This can be automated</h3>
            <div>
                <p>
                    To let the migration steps run automatically, you can add &lt;add key=&quot;AutoMigrateEPiServer&quot; value=&quot;true&quot; /&gt; 
                        to the appSettings section in web.config.
                        Next time when you update your site via nuget packages, the migration process will be run automatically.
                        If all steps run successfully, you'll be able to redirect to the home page. 
                        Otherwise errors will be displayed in migration page and will also be logged via log4net.               
                </p>
            </div>
            <h3>Backing up database</h3>
            <div>
                <p>
                    The migration steps cannot be undone. If you want to be able to roll back the changes you should take a backup of your databases (CMS and Commerce).
                </p>
            </div>   
            <% } %>

            <% if(Model.ShowHelp)
               { %>
                <%=Html.ActionLink("Less information", "Index", new { showHelp = false, showHistory = Model.ShowHistory })%>
            <% } else { %>
                <%=Html.ActionLink("More information", "Index", new { showHelp = true, showHistory = Model.ShowHistory })%>
            <% } %>
            
               <h2>Status</h2>
           
            <% if (Model.CanStartMigrationJob)
               { %>
                <% Html.BeginForm("Run", "Migrate"); %>
                <p>You have pending migration steps
                <input id="exceutePendingSteps" type="submit" class="epi-chromeless epi-visibleLink" value="Execute all pending steps"></p>
                <% Html.EndForm(); %>
            <% } %>

            <p><strong><span id="migrationStatusMessage"><%= Model.StatusMessage %></span></strong></p>
            <h3>Migration Steps</h3>
            <div class="dgrid epi-plain-grid epi-plain-grid-modal epi-plain-grid--margin-bottom epi-plain-grid--cell-borders">
                <table class="dgrid-row-table">
                    <tr class="dgrid-header">
                        <th class="dgrid-cell epi-grid-column--bold">Name</th>
                        <th class="dgrid-cell epi-grid-column--bold">Description</th>
                        <th class="dgrid-cell epi-grid-column--bold">Status</th>
                        <th class="dgrid-cell epi-grid-column--bold">Last Run</th>
                    </tr>
                    <% foreach (var step in Model.Steps)
                       { %>
                    <tr>
                        <td class="dgrid-cell"><%: step.Name %></td>
                        <td class="dgrid-cell"><%: step.Description %></td>
                        <td class="dgrid-cell"><span class="dijitInline dijitIcon <%: step.StatusIcon %>"></span></td>
                        <td class="dgrid-cell"><%: step.LastRun %></td>
                    </tr>
                    <% } %>
                </table>
                <% if(Model.ShowHistory)
                   { %>
                    <%=Html.ActionLink("Show recent steps", "Index", new { showHistory = false, showHelp = Model.ShowHelp })%>
                    <%}else{ %>
                    <%=Html.ActionLink("Show all steps", "Index", new { showHistory = true, showHelp = Model.ShowHelp })%>
                <% } %>
            
            </div>

           
         
        </div>
        <% if (Model.Messages.Count() > 0)
           { %>
            <h3 id="Log">Log</h3>
            <div class="half-height half-height--scrollable">
                <ul class="epi-chromeless epi-list">
                    <% foreach (var message in Model.Messages){ %>
                    <li><span class="epi-secondaryText"><%= message.ToHtmlString() %></span></li>
                    <% } %>
                </ul>
            </div>
        <% } %>
    </div>
</body>
</html>
